<?php

/**
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/roundcube/roundcube-webmail/plugin-enigma/
*/

$labels['encryption'] = 'Kryptering';
$labels['keyname'] = 'Navn';
$labels['keyid'] = 'NøgleID';
$labels['fingerprint'] = 'Fingeravtryk';
$labels['typeencrypt'] = 'Krypter';
$labels['subkeyid'] = 'ID';
$labels['subkeycreated'] = 'Oprettet';
$labels['subkeyexpires'] = 'Udløber';
$labels['expiresnever'] = 'aldrig';
$labels['unknown'] = 'ukendt';
$labels['userid'] = 'ID';
$labels['valid'] = 'valid';
$labels['createkeys'] = 'Opret et nyt nøglepar';
$labels['keyremove'] = 'Fjern';
$labels['keychpass'] = 'Skift kodeord:';
$labels['newkeypass'] = 'Adgangskode';
$labels['keyimportlabel'] = 'Importer fra fil';
?>
