<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/timezones/
*/

$labels['tz:africa'] = 'Aafrika';
$labels['tz:africa:abidjan'] = 'Abidjan';
$labels['tz:africa:accra'] = 'Accra';
$labels['tz:africa:addis_ababa'] = 'Addis Ababa';
$labels['tz:africa:algiers'] = 'Algiers';
$labels['tz:africa:asmara'] = 'Asmara';
$labels['tz:africa:bamako'] = 'Bamako';
$labels['tz:africa:bangui'] = 'Bangui';
$labels['tz:africa:banjul'] = 'Banjul';
$labels['tz:africa:bissau'] = 'Bissau';
$labels['tz:africa:blantyre'] = 'Blantyre';
$labels['tz:africa:brazzaville'] = 'Brazzaville';
$labels['tz:africa:bujumbura'] = 'Bujumbura';
$labels['tz:africa:cairo'] = 'Kairo';
$labels['tz:africa:casablanca'] = 'Casablanca';
$labels['tz:africa:ceuta'] = 'Ceuta';
$labels['tz:africa:conakry'] = 'Conakry';
$labels['tz:africa:dakar'] = 'Dakar';
$labels['tz:africa:dar_es_salaam'] = 'Dar es Salaam';
$labels['tz:africa:djibouti'] = 'Djibouti';
$labels['tz:africa:douala'] = 'Douala';
$labels['tz:africa:el_aaiun'] = 'El Aaiun';
$labels['tz:africa:freetown'] = 'Freetown';
$labels['tz:africa:gaborone'] = 'Gaborone';
$labels['tz:africa:harare'] = 'Harare';
$labels['tz:africa:johannesburg'] = 'Johannesburg';
$labels['tz:africa:juba'] = 'Juba';
$labels['tz:africa:kampala'] = 'Kampala';
$labels['tz:africa:khartoum'] = 'Hartum';
$labels['tz:africa:kigali'] = 'Kigali';
$labels['tz:africa:kinshasa'] = 'Kinshasa';
$labels['tz:africa:lagos'] = 'Lagos';
$labels['tz:africa:libreville'] = 'Libreville';
$labels['tz:africa:luanda'] = 'Luanda';
$labels['tz:africa:lubumbashi'] = 'Lubumbashi';
$labels['tz:africa:lusaka'] = 'Lusaka';
$labels['tz:africa:malabo'] = 'Malabo';
$labels['tz:africa:maputo'] = 'Maputo';
$labels['tz:africa:maseru'] = 'Maseru';
$labels['tz:africa:mbabane'] = 'Mbabane';
$labels['tz:africa:mogadishu'] = 'Mogadishu';
$labels['tz:africa:monrovia'] = 'Monrovia';
$labels['tz:africa:nairobi'] = 'Nairobi';
$labels['tz:africa:ndjamena'] = 'Ndjamena';
$labels['tz:africa:niamey'] = 'Niamey';
$labels['tz:africa:nouakchott'] = 'Nouakchott';
$labels['tz:africa:ouagadougou'] = 'Ouagadougou';
$labels['tz:africa:porto-novo'] = 'Porto-Novo';
$labels['tz:africa:tripoli'] = 'Tripoli';
$labels['tz:africa:tunis'] = 'Tunis';
$labels['tz:africa:windhoek'] = 'Windhoek';
$labels['tz:america'] = 'Ameerika';
$labels['tz:america:adak'] = 'Adak';
$labels['tz:america:anchorage'] = 'Anchorage';
$labels['tz:america:anguilla'] = 'Anguilla';
$labels['tz:america:antigua'] = 'Antigua';
$labels['tz:america:araguaina'] = 'Araguaína';
$labels['tz:america:argentina'] = 'Argentina';
$labels['tz:america:aruba'] = 'Aruba';
$labels['tz:america:atikokan'] = 'Atikokan';
$labels['tz:america:bahia'] = 'Bahia';
$labels['tz:america:bahia_banderas'] = 'Bahia Banderas';
$labels['tz:america:barbados'] = 'Barbados';
$labels['tz:america:belem'] = 'Belém';
$labels['tz:america:belize'] = 'Belize';
$labels['tz:america:blanc-sablon'] = 'Blanc-Sablon';
$labels['tz:america:boa_vista'] = 'Boa Vista';
$labels['tz:america:bogota'] = 'Bogota';
$labels['tz:america:boise'] = 'Boise';
$labels['tz:america:cambridge_bay'] = 'Ikaluktutiak';
$labels['tz:america:campo_grande'] = 'Campo Grande';
$labels['tz:america:cancun'] = 'Cancun';
$labels['tz:america:caracas'] = 'Caracas';
$labels['tz:america:cayenne'] = 'Cayenne';
$labels['tz:america:cayman'] = 'Cayman';
$labels['tz:america:chicago'] = 'Chicago';
$labels['tz:america:chihuahua'] = 'Chihuahua';
$labels['tz:america:costa_rica'] = 'Costa Rica';
$labels['tz:america:creston'] = 'Creston';
$labels['tz:america:cuiaba'] = 'Cuiaba';
$labels['tz:america:danmarkshavn'] = 'Danmarkshavn';
$labels['tz:america:dawson'] = 'Dawson';
$labels['tz:america:dawson_creek'] = 'Dawson Creek';
$labels['tz:america:denver'] = 'Denver';
$labels['tz:america:detroit'] = 'Detroit';
$labels['tz:america:dominica'] = 'Dominica';
$labels['tz:america:edmonton'] = 'Edmonton';
$labels['tz:america:eirunepe'] = 'Eirunepe';
$labels['tz:america:el_salvador'] = 'El Salvador';
$labels['tz:america:fort_nelson'] = 'Fort Nelson';
$labels['tz:america:fortaleza'] = 'Fortaleza';
$labels['tz:america:glace_bay'] = 'Glace Bay';
$labels['tz:america:godthab'] = 'Nuuk';
$labels['tz:america:goose_bay'] = 'Goose Bay';
$labels['tz:america:grand_turk'] = 'Grand Turk';
$labels['tz:america:grenada'] = 'Grenada';
$labels['tz:america:guadeloupe'] = 'Guadeloupe';
$labels['tz:america:guatemala'] = 'Guatemala';
$labels['tz:america:guayaquil'] = 'Guayaquil';
$labels['tz:america:guyana'] = 'Guyana';
$labels['tz:america:halifax'] = 'Halifax';
$labels['tz:america:havana'] = 'Havanna';
$labels['tz:america:hermosillo'] = 'Hermosillo';
$labels['tz:america:indiana'] = 'Indiana';
$labels['tz:america:indiana:indianapolis'] = 'Indianapolis';
$labels['tz:america:indiana:knox'] = 'Knox';
$labels['tz:america:inuvik'] = 'Inuvik';
$labels['tz:america:iqaluit'] = 'Iqaluit';
$labels['tz:america:jamaica'] = 'Jamaica';
$labels['tz:america:juneau'] = 'Juneau';
$labels['tz:america:kentucky'] = 'Kentucky';
$labels['tz:america:kentucky:louisville'] = 'Louisville';
$labels['tz:america:kralendijk'] = 'Kralendijk';
$labels['tz:america:la_paz'] = 'La Paz';
$labels['tz:america:lima'] = 'Lima';
$labels['tz:america:los_angeles'] = 'Los Angeles';
$labels['tz:america:lower_princes'] = 'Lower Princes';
$labels['tz:america:maceio'] = 'Maceio';
$labels['tz:america:managua'] = 'Managua';
$labels['tz:america:manaus'] = 'Manaus';
$labels['tz:america:marigot'] = 'Marigot';
$labels['tz:america:martinique'] = 'Martinique';
$labels['tz:america:matamoros'] = 'Matamoros';
$labels['tz:america:mazatlan'] = 'Mazatlan';
$labels['tz:america:menominee'] = 'Menominee';
$labels['tz:america:merida'] = 'Mérida';
$labels['tz:america:metlakatla'] = 'Metlakatla';
$labels['tz:america:mexico_city'] = 'México';
$labels['tz:america:miquelon'] = 'Miquelon';
$labels['tz:america:moncton'] = 'Moncton';
$labels['tz:america:monterrey'] = 'Monterrey';
$labels['tz:america:montevideo'] = 'Montevideo';
$labels['tz:america:montserrat'] = 'Montserrat';
$labels['tz:america:nassau'] = 'Nassau';
$labels['tz:america:new_york'] = 'New York';
$labels['tz:america:nipigon'] = 'Nipigon';
$labels['tz:america:nome'] = 'Nome';
$labels['tz:america:noronha'] = 'Noronha';
$labels['tz:america:north_dakota'] = 'Põhja-Dakota';
$labels['tz:america:ojinaga'] = 'Ojinaga';
$labels['tz:america:panama'] = 'Panama';
$labels['tz:america:pangnirtung'] = 'Pangnirtung';
$labels['tz:america:paramaribo'] = 'Paramaribo';
$labels['tz:america:phoenix'] = 'Phoenix';
$labels['tz:america:port-au-prince'] = 'Port-au-Prince';
$labels['tz:america:port_of_spain'] = 'Port of Spain';
$labels['tz:america:porto_velho'] = 'Porto Velho';
$labels['tz:america:puerto_rico'] = 'Puerto Rico';
$labels['tz:america:rainy_river'] = 'Rainy River';
$labels['tz:america:rankin_inlet'] = 'Rankin Inlet';
$labels['tz:america:recife'] = 'Recife';
$labels['tz:america:regina'] = 'Regina';
$labels['tz:america:resolute'] = 'Resolute';
$labels['tz:america:rio_branco'] = 'Rio Branco';
$labels['tz:america:santarem'] = 'Santarém';
$labels['tz:america:santiago'] = 'Santiago';
$labels['tz:america:santo_domingo'] = 'Santo Domingo';
$labels['tz:america:sao_paulo'] = 'São Paulo';
$labels['tz:america:scoresbysund'] = 'Scoresbysund';
$labels['tz:america:sitka'] = 'Sitka';
$labels['tz:america:swift_current'] = 'Swift Current';
$labels['tz:america:tegucigalpa'] = 'Tegucigalpa';
$labels['tz:america:thule'] = 'Thule';
$labels['tz:america:thunder_bay'] = 'Thunder Bay';
$labels['tz:america:tijuana'] = 'Tijuana';
$labels['tz:america:toronto'] = 'Toronto';
$labels['tz:america:tortola'] = 'Tortola';
$labels['tz:america:vancouver'] = 'Vancouver';
$labels['tz:america:whitehorse'] = 'Whitehorse';
$labels['tz:america:winnipeg'] = 'Winnipeg';
$labels['tz:america:yakutat'] = 'Yakutat';
$labels['tz:america:yellowknife'] = 'Yellowknife';
$labels['tz:antarctica'] = 'Antarktika';
$labels['tz:antarctica:casey'] = 'Casey';
$labels['tz:antarctica:davis'] = 'Davis';
$labels['tz:antarctica:macquarie'] = 'Macquarie';
$labels['tz:antarctica:mawson'] = 'Mawson';
$labels['tz:antarctica:mcmurdo'] = 'McMurdo';
$labels['tz:antarctica:palmer'] = 'Palmer';
$labels['tz:antarctica:rothera'] = 'Rothera';
$labels['tz:antarctica:syowa'] = 'Syowa';
$labels['tz:antarctica:troll'] = 'Troll';
$labels['tz:antarctica:vostok'] = 'Vostok';
$labels['tz:arctic'] = 'Arktika';
$labels['tz:arctic:longyearbyen'] = 'Longyearbyen';
$labels['tz:asia'] = 'Aasia';
