<?php

/**
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/roundcube/roundcube-webmail/plugin-enigma/
*/

$labels['encryption'] = 'Encriptació';
$labels['enigmacerts'] = 'Certificats S/MIME';
$labels['enigmakeys'] = 'Claus PGP';
$labels['keyname'] = 'Nom';
$labels['keyid'] = 'ID de la clau';
$labels['keyuserid'] = 'ID de l\'usuari';
$labels['keytype'] = 'Tipus de clau';
$labels['fingerprint'] = 'Empremta digital';
$labels['subkeys'] = 'Subclaus';
$labels['basicinfo'] = 'Informació bàsica';
$labels['userids'] = 'Usuaris addicionals';
$labels['typepublickey'] = 'clau pública';
$labels['typekeypair'] = 'parella de claus';
$labels['keyattfound'] = 'Aquest missatge conté clau(s) PGP adjunt(s).';
$labels['keyattimport'] = 'Importa clau(s)';
$labels['typesign'] = 'Signa';
$labels['typeencrypt'] = 'Xifrar';
$labels['typecert'] = 'Certifica';
$labels['subkeyid'] = 'ID';
$labels['subkeyalgo'] = 'Algorisme';
$labels['subkeycreated'] = 'Creat';
$labels['subkeyexpires'] = 'Caduca';
$labels['subkeyusage'] = 'Ús';
$labels['expiresnever'] = 'mai';
$labels['unknown'] = 'desconegut';
$labels['uservalid'] = 'Vàlid';
$labels['userid'] = 'ID';
$labels['valid'] = 'vàlid';
$labels['supportencryption'] = 'Activa l\'encriptació i signat del missatge';
$labels['supportsignatures'] = 'Activa la verificació de les signatures del missatge';
$labels['supportdecryption'] = 'Activa la desencriptació del missatge';
$labels['signdefault'] = 'Signa tots els missatges per defecte';
$labels['encryptdefault'] = 'Encripta tots els missatges per defecte';
$labels['nminutes'] = '$m minut(s)';
$labels['wholesession'] = 'a tota la sessió';
$labels['createkeys'] = 'Crea un nou parell de claus';
$labels['importkeys'] = 'Importa clau(s)';
$labels['exportkeys'] = 'Exporta clau(s)';
$labels['keyremove'] = 'Suprimeix';
$labels['keydisable'] = 'Desactiva';
$labels['keyrevoke'] = 'Revoca';
$labels['keysend'] = 'Envia la clau pública en un missatge';
$labels['keychpass'] = 'Canvia la contrasenya';
$labels['newkeyident'] = 'Identitat';
$labels['newkeypass'] = 'Contrasenya';
$labels['newkeypassconfirm'] = 'Confirma la contrasenya';
$labels['key2048'] = '2048 bits - per defecte';
$labels['key4096'] = '4096 bits - més segur';
$labels['keygenerating'] = 'S\'estan generant les claus...';
$labels['encryptionoptions'] = 'Opcions d\'encriptació...';
$labels['encryptmsg'] = 'Encripta aquest missatge';
$labels['signmsg'] = 'Signa digitalment aquest missatge';
$labels['enterkeypasstitle'] = 'Introduïu la contrasenya de la clau';
$labels['enterkeypass'] = 'Cal una contrasenya per desblocar la clau secreta ($keyid) per l\'usuari: $user.';
?>
