<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Archief';
$labels['buttontitle'] = 'Archiveer dit bericht';
$labels['archived'] = 'Succesvol gearchiveerd';
$labels['archivedreload'] = 'Succesvol gearchiveerd. Herlaad de pagina om de nieuwe archiefmappen te bekijken.';
$labels['archiveerror'] = 'Sommige berichten kunnen niet gearchiveerd worden';
$labels['archivefolder'] = 'Archief';
$labels['settingstitle'] = 'Archiveren';
$labels['archivetype'] = 'Archief opdelen in';
$labels['archivetypeyear'] = 'Jaar (bijv. Archief/2012)';
$labels['archivetypemonth'] = 'Maand (bijv. Archief/2012/06)';
$labels['archivetypetbmonth'] = 'Maand - Thunderbird compatibel (bijv. Archief/2012/06)';
$labels['archivetypefolder'] = 'Originele map';
$labels['archivetypesender'] = 'Afzender e-mail';
$labels['unkownsender'] = 'onbekend';
$labels['readonarchive'] = 'Markeer bericht al gelezen op archiveren';
?>
