<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/timezones/
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = 'África';
$labels['tz:africa:abidjan'] = 'Abidjan';
$labels['tz:africa:accra'] = 'Accra';
$labels['tz:africa:addis_ababa'] = 'Adís Abeba';
$labels['tz:africa:algiers'] = 'Argel';
$labels['tz:africa:asmara'] = 'Asmara';
$labels['tz:africa:bamako'] = 'Bamako';
$labels['tz:africa:cairo'] = 'Cairo';
$labels['tz:africa:ceuta'] = 'Ceuta';
$labels['tz:africa:dakar'] = 'Dakar';
$labels['tz:america'] = 'América';
$labels['tz:america:anchorage'] = 'Anchorage';
$labels['tz:america:antigua'] = 'Antigua';
$labels['tz:america:argentina'] = 'Argentina';
$labels['tz:america:argentina:buenos_aires'] = 'Buenos Aires';
$labels['tz:america:argentina:cordoba'] = 'Córdoba';
$labels['tz:america:argentina:la_rioja'] = 'La Rioja';
$labels['tz:america:argentina:mendoza'] = 'Mendoza';
$labels['tz:america:argentina:salta'] = 'Salta';
$labels['tz:america:argentina:san_juan'] = 'San Juan';
$labels['tz:america:argentina:san_luis'] = 'San Luis';
$labels['tz:america:asuncion'] = 'Asunción';
$labels['tz:america:bogota'] = 'Bogotá';
$labels['tz:america:campo_grande'] = 'Campo Grande';
$labels['tz:america:cancun'] = 'Cancún';
$labels['tz:america:caracas'] = 'Caracas';
$labels['tz:america:chicago'] = 'Chicago';
$labels['tz:america:chihuahua'] = 'Chihuahua';
$labels['tz:america:costa_rica'] = 'Costa Rica';
$labels['tz:america:denver'] = 'Denver';
$labels['tz:america:detroit'] = 'Detroit';
$labels['tz:america:dominica'] = 'Dominica';
$labels['tz:america:el_salvador'] = 'El Salvador';
$labels['tz:america:fortaleza'] = 'Fortaleza';
$labels['tz:america:grenada'] = 'Granada';
$labels['tz:america:guadeloupe'] = 'Guadalupe';
$labels['tz:america:guatemala'] = 'Guatemala';
$labels['tz:america:guayaquil'] = 'Guayaquil';
$labels['tz:america:havana'] = 'Habana';
$labels['tz:america:hermosillo'] = 'Hermosillo';
$labels['tz:america:indiana'] = 'Indiana';
$labels['tz:america:indiana:indianapolis'] = 'Indianápolis';
$labels['tz:america:jamaica'] = 'Jamaica';
$labels['tz:america:kentucky'] = 'Kentucky';
$labels['tz:america:la_paz'] = 'La Paz';
$labels['tz:america:lima'] = 'Lima';
$labels['tz:america:los_angeles'] = 'Los Ángeles';
$labels['tz:america:managua'] = 'Managua';
$labels['tz:america:matamoros'] = 'Matamoros';
$labels['tz:america:merida'] = 'Mérida';
$labels['tz:america:mexico_city'] = 'Ciudad de México';
$labels['tz:america:monterrey'] = 'Monterrey';
$labels['tz:america:montevideo'] = 'Montevideo';
$labels['tz:america:new_york'] = 'Nueva York';
$labels['tz:america:panama'] = 'Panamá';
$labels['tz:america:paramaribo'] = 'Paramaribo';
$labels['tz:america:phoenix'] = 'Phoenix';
$labels['tz:america:port_of_spain'] = 'Puerto de España';
$labels['tz:america:puerto_rico'] = 'Puerto Rico';
$labels['tz:america:santiago'] = 'Santiago';
$labels['tz:america:santo_domingo'] = 'Santo Domingo';
$labels['tz:america:sao_paulo'] = 'Sao Paulo';
$labels['tz:america:tegucigalpa'] = 'Tegucigalpa';
$labels['tz:america:tijuana'] = 'Tijuana';
$labels['tz:america:toronto'] = 'Toronto';
$labels['tz:asia'] = 'Asia';
$labels['tz:asia:dubai'] = 'Dubái';
$labels['tz:asia:gaza'] = 'Gaza';
$labels['tz:asia:hong_kong'] = 'Hong Kong';
$labels['tz:asia:karachi'] = 'Karachi';
$labels['tz:asia:kuala_lumpur'] = 'Kuala Lumpur';
$labels['tz:asia:kuwait'] = 'Kuwait';
$labels['tz:asia:macau'] = 'Macao';
$labels['tz:asia:manila'] = 'Manila';
$labels['tz:asia:nicosia'] = 'Nicosia';
$labels['tz:asia:novosibirsk'] = 'Novosibirsk';
$labels['tz:asia:pyongyang'] = 'Pyongyang';
$labels['tz:asia:qatar'] = 'Qatar';
$labels['tz:asia:seoul'] = 'Seúl';
$labels['tz:asia:singapore'] = 'Singapur';
$labels['tz:asia:taipei'] = 'Taipei';
$labels['tz:asia:tbilisi'] = 'Tbilisi';
$labels['tz:asia:tokyo'] = 'Tokio';
$labels['tz:asia:ulaanbaatar'] = 'Ulán Bator';
$labels['tz:asia:vladivostok'] = 'Vladivostok';
$labels['tz:atlantic'] = 'Atlántico';
$labels['tz:atlantic:azores'] = 'Azores';
$labels['tz:atlantic:canary'] = 'Islas Canarias';
$labels['tz:atlantic:cape_verde'] = 'Cabo Verde';
$labels['tz:atlantic:madeira'] = 'Madeira';
$labels['tz:australia'] = 'Australia';
$labels['tz:australia:darwin'] = 'Darwin';
$labels['tz:australia:perth'] = 'Perth';
$labels['tz:australia:sydney'] = 'Sydney';
$labels['tz:europe'] = 'Europa';
$labels['tz:europe:amsterdam'] = 'Amsterdam';
$labels['tz:europe:andorra'] = 'Andorra';
$labels['tz:europe:belgrade'] = 'Belgrado';
$labels['tz:europe:bratislava'] = 'Bratislava';
$labels['tz:europe:budapest'] = 'Budapest';
$labels['tz:europe:dublin'] = 'Dublín';
$labels['tz:europe:gibraltar'] = 'Gibraltar Español';
$labels['tz:europe:istanbul'] = 'Estambul';
$labels['tz:europe:kiev'] = 'Kiev';
$labels['tz:europe:lisbon'] = 'Lisboa';
$labels['tz:europe:london'] = 'Londres';
$labels['tz:europe:luxembourg'] = 'Luxemburgo';
$labels['tz:europe:madrid'] = 'Madrid';
$labels['tz:europe:monaco'] = 'Mónaco';
$labels['tz:europe:moscow'] = 'Moscú';
$labels['tz:europe:oslo'] = 'Oslo';
$labels['tz:europe:paris'] = 'París';
$labels['tz:europe:prague'] = 'Praga';
$labels['tz:europe:rome'] = 'Roma';
$labels['tz:europe:san_marino'] = 'San Marino';
$labels['tz:europe:vatican'] = 'Ciudad del Vaticano';
$labels['tz:europe:vienna'] = 'Viena';
$labels['tz:europe:zurich'] = 'Zúrich';
